@@ -352,7 +352,7 @@ def p(level,fmt,*info):#输出信息
         if swid==0 or logid==0:return   #事务id或者调用id为0则返回
         insertSql = "insert into sw_detaillog (dispathno,swid,no,log_time,log_msg,log_level) values (:dispathno,:swid,:no,sysdate,:log_msg,:log_level)"
         cur = swdb.conn.cursor()
-        cur.setinputsizes(log_msg=cx_Oracle.BLOB)
+        cur.setinputsizes(log_msg=swdb.BLOB)
         cur.execute(insertSql, {'dispathno':logid,'swid':swid,'no':logno,'log_msg':sinfo.encode("gbk"),'log_level':level})
         logno = logno + 1
         swdb.conn.commit()
@@ -369,10 +369,18 @@ def sjbj(sjhm,nr,td="AB"):  #手机报警
 class c_xx(object):   #消息处理
     def __init__(self):
         self.cc=c_oracle("xtjk@cc",yslj=True)
+    def dwx(self,组,消息内容,标题=None,消息保存天数=30):
+        self.dx(组,消息内容,标题,消息保存天数)
+        self.wx(组,消息内容,标题,消息保存天数)
     def dx(self,组,消息内容,标题=None,消息保存天数=30):
         s=sys._getframe(1)
         标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
         self.cc.execute("select f_dx(:z,:xxnr,:bt,:ts) from dual",z=组,xxnr=消息内容,bt=标题,ts=消息保存天数)
+    def gzt(self,组,消息标识,消息内容,标题=None,消息保存天数=30): #工作台消息
+        s=sys._getframe(1)
+        标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
+        if 消息内容=="":消息内容="正常"
+        self.cc.execute("select f_gzt(:z,:xxnr,:bt,:ts) from dual",z=组,xxnr="%s|1|%s" %(消息标识,消息内容),bt=标题,ts=消息保存天数)
     def wx(self,组,消息内容,标题=None,消息保存天数=30):
         s=sys._getframe(1)
         标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
@@ -440,7 +448,7 @@ swdb=c_oracle(yslj=True,raiseExp=True)
 swid=swenv("swid",0)
 logid=swenv("logid",0)
 loglevel=swenv("loglevel",5)
-swrq=swenv("swrq","")
+swrq=swenv("swrq",dqrq)
 oraconn=swenv("oracle","")
 if oraconn!="":
     swdb.connect(oraconn)
